==> ba-react-fetch-api-0.12.25.tgz: package/FetchAPI/entities/index.js <==
// @flow
import batch from './batch';
import bulkUpdate from './bulk/update';
import collaborationCall from './details/collaboration-call';
import campaigns from './list/campaigns';
import campaignAttach from './details/campaign-attach';
import campaignDetach from './details/campaign-detach';
import cases from './list/cases';
import caseAttach from './details/case-attach';
import companies from './list/companies';
import comments from './list/comments';
import contact from './details/contact';
import contactAttach from './details/contact-attach';
import contactDetach from './details/contact-detach';
import contacts from './list/contacts';
import documents from './list/documents';
import dictionaries from './list/dictionaries';
import driveFiles from './list/drive-files';
import globalSearch from './list/global-search';
import expenses from './list/expenses';
import folders from './list/folders';
import inviteProjectExternal from './details/inviteProjectExternal';
import inviteProjectMember from './details/inviteProjectMember';
import inviteWorkspaceExternal from './details/inviteWorkspaceExternal';
import inviteWorkspaceMember from './details/inviteWorkspaceMember';
import invoices from './list/invoices';
import streamGroup from './details/stream-group';
import streamGroups from './list/stream-groups';
import leads from './list/leads';
import listingPurchase from './details/listing-purchase';
import listingTodoList from './details/listing-todo-list';
import listings from './list/listings';
import openHouses from './list/open-houses';
import openHouse from './details/open-house';
import opportunities from './list/opportunities';
import projects from './list/projects';
import properties from './list/properties';
import relatedCampaigns from './list/related-campaigns';
import relatedCases from './list/related-cases';
import relatedCompanies from './list/related-companies';
import relatedContacts from './list/related-contacts';
import relatedLeads from './list/related-leads';
import relatedListings from './list/related-listings';
import relatedOffers from './list/related-offers';
import relatedOpportunities from './list/related-opportunities';
import relatedRequests from './list/related-requests';
import relatedUsers from './list/related-users';
import requests from './list/requests';
import requestDetach from './details/request-detach';
import requestAttach from './details/request-attach';
import socialInterests from './list/social-interests';
import stageHistory from './list/stage-history';
import stages from './list/stages';
import task from './details/task';
import note from './details/note';
import tasks from './list/tasks';
import tasksBulk from './bulk/tasks';
import taskComment from './details/task-comment';
import tasksComments from './list/tasks-comments';
import tasksSections from './list/tasks-sections';
import transactions from './list/transactions';
import workspaceMembers from './list/workspace-members';
import workspaces from './list/workspaces';
import relatedEvents from './list/related-events';
import relatedTasks from './list/related-tasks';
import calendarEvent from './details/calendar-event';
import calendarEvents from './list/calendar-events';
import calendarCategories from './list/calendar-categories';
import calendarCategory from './details/calendar-category';
import calendarTypes from './list/calendar-types';
import user from './details/user';
import users from './list/users';
import userAttach from './details/user-attach';
import userDetach from './details/user-detach';
import calendarType from './details/calendar-type';
import activityList from './list/activity-list';
import workspace from './details/workspace';
import file from './details/file';
import files from './list/files';
import campaign from './details/campaign';
import caseDetails from './details/case';
import caseDetach from './details/case-detach';
import offerDetach from './details/offer-detach';
import company from './details/company';
import companyAttach from './details/company-attach';
import companyDetach from './details/company-detach';
import favorite from './details/favorite';
import lead from './details/lead';
import leadDetach from './details/lead-detach';
import leadAttach from './details/lead-attach';
import listing from './details/listing';
import listingDetach from './details/listing-detach';
import opportunity from './details/opportunity';
import opportunityAttach from './details/opportunity-attach';
import opportunityDetach from './details/opportunity-detach';
import property from './details/property';
import request from './details/request';
import transaction from './details/transaction';
import projectTask from './details/project-task';
import listView from './details/list-view';
import listViews from './list/list-views';
import emails from './list/emails';
import email from './details/email';
import emailSend from './details/email-send';
import emailForward from './details/email-forward';
import workspaceActivities from './list/workspace-activities';
import workspaceActivity from './details/workspace-activity';
import recent from './list/recent';
import clearRecent from './list/clear-recent';
import etag from './details/etag';

export default (baseURL: string) => ({
	activityList           : activityList(baseURL),
	batch                  : batch(baseURL),
	bulkUpdate             : bulkUpdate(baseURL),
	calendarCategories     : calendarCategories(baseURL),
	calendarCategory       : calendarCategory(baseURL),
	calendarEvents         : calendarEvents(baseURL),
	calendarType           : calendarType(baseURL),
	calendarTypes          : calendarTypes(baseURL),
	campaign               : campaign(baseURL),
	campaignAttach         : campaignAttach(baseURL),
	campaignDetach         : campaignDetach(baseURL),
	campaigns              : campaigns(baseURL),
	caseAttach             : caseAttach(baseURL),
	caseDetach             : caseDetach(baseURL),
	caseDetails            : caseDetails(baseURL),
	cases                  : cases(baseURL),
	clearRecent            : clearRecent(baseURL),
	collaborationCall      : collaborationCall(baseURL),
	comments               : comments(baseURL),
	companies              : companies(baseURL),
	company                : company(baseURL),
	companyAttach          : companyAttach(baseURL),
	companyDetach          : companyDetach(baseURL),
	contact                : contact(baseURL),
	contactAttach          : contactAttach(baseURL),
	contactDetach          : contactDetach(baseURL),
	contacts               : contacts(baseURL),
	dictionaries           : dictionaries(baseURL),
	documents              : documents(baseURL),
	driveFiles             : driveFiles(baseURL),
	email                  : email(baseURL),
	emailForward           : emailForward(baseURL),
	emails                 : emails(baseURL),
	emailSend              : emailSend(baseURL),
	etag                   : etag(baseURL),
	event                  : calendarEvent(baseURL),
	expenses               : expenses(baseURL),
	favorite               : favorite(baseURL),
	file                   : file(baseURL),
	files                  : files(baseURL),
	folders                : folders(baseURL),
	globalSearch           : globalSearch(baseURL),
	inviteProjectExternal  : inviteProjectExternal(baseURL),
	inviteProjectMember    : inviteProjectMember(baseURL),
	inviteWorkspaceExternal: inviteWorkspaceExternal(baseURL),
	inviteWorkspaceMember  : inviteWorkspaceMember(baseURL),
	invoices               : invoices(baseURL),
	lead                   : lead(baseURL),
	leadAttach             : leadAttach(baseURL),
	leadDetach             : leadDetach(baseURL),
	leads                  : leads(baseURL),
	listing                : listing(baseURL),
	listingDetach          : listingDetach(baseURL),
	listingPurchase        : listingPurchase(baseURL),
	listingTodoList        : listingTodoList(baseURL),
	listings               : listings(baseURL),
	listView               : listView(baseURL),
	listViews              : listViews(baseURL),
	note                   : note(baseURL),
	offerDetach            : offerDetach(baseURL),
	openHouse              : openHouse(baseURL),
	openHouses             : openHouses(baseURL),
	opportunities          : opportunities(baseURL),
	opportunity            : opportunity(baseURL),
	opportunityAttach      : opportunityAttach(baseURL),
	opportunityDetach      : opportunityDetach(baseURL),
	projects               : projects(baseURL),
	projectTask            : projectTask(baseURL),
	properties             : properties(baseURL),
	property               : property(baseURL),
	recent                 : recent(baseURL),
	relatedCampaigns       : relatedCampaigns(baseURL),
	relatedCases           : relatedCases(baseURL),
	relatedCompanies       : relatedCompanies(baseURL),
	relatedContacts        : relatedContacts(baseURL),
	relatedEvents          : relatedEvents(baseURL),
	relatedLeads           : relatedLeads(baseURL),
	relatedListings        : relatedListings(baseURL),
	relatedOffers          : relatedOffers(baseURL),
	relatedOpportunities   : relatedOpportunities(baseURL),
	relatedRequests        : relatedRequests(baseURL),
	relatedTasks           : relatedTasks(baseURL),
	relatedUsers           : relatedUsers(baseURL),
	request                : request(baseURL),
	requestAttach          : requestAttach(baseURL),
	requestDetach          : requestDetach(baseURL),
	requests               : requests(baseURL),
	socialInterests        : socialInterests(baseURL),
	stageHistory           : stageHistory(baseURL),
	stages                 : stages(baseURL),
	streamGroup            : streamGroup(baseURL),
	streamGroups           : streamGroups(baseURL),
	task                   : task(baseURL),
	taskComment            : taskComment(baseURL),
	tasks                  : tasks(baseURL),
	tasksBulk              : tasksBulk(baseURL),
	tasksComments          : tasksComments(baseURL),
	tasksSections          : tasksSections(baseURL),
	transaction            : transaction(baseURL),
	transactions           : transactions(baseURL),
	user                   : user(baseURL),
	userAttach             : userAttach(baseURL),
	userDetach             : userDetach(baseURL),
	users                  : users(baseURL),
	workspace              : workspace(baseURL),
	workspaceActivities    : workspaceActivities(baseURL),
	workspaceActivity      : workspaceActivity(baseURL),
	workspaceMembers       : workspaceMembers(baseURL),
	workspaces             : workspaces(baseURL),
});

==> ba-react-fetch-api-0.12.28.tgz: package/FetchAPI/entities/index.js <==
// @flow
import batch from './batch';
import bulkUpdate from './bulk/update';
import collaborationCall from './details/collaboration-call';
import campaigns from './list/campaigns';
import campaignAttach from './details/campaign-attach';
import campaignDetach from './details/campaign-detach';
import cases from './list/cases';
import caseAttach from './details/case-attach';
import companies from './list/companies';
import comments from './list/comments';
import contact from './details/contact';
import contactAttach from './details/contact-attach';
import contactDetach from './details/contact-detach';
import contacts from './list/contacts';
import documents from './list/documents';
import dictionaries from './list/dictionaries';
import driveFiles from './list/drive-files';
import globalSearch from './list/global-search';
import expenses from './list/expenses';
import folders from './list/folders';
import inviteProjectExternal from './details/invite-project-external';
import inviteProjectMember from './details/invite-project-member';
import inviteWorkspaceExternal from './details/invite-workspace-external';
import inviteWorkspaceMember from './details/invite-workspace-member';
import invoices from './list/invoices';
import streamGroup from './details/stream-group';
import streamGroups from './list/stream-groups';
import leads from './list/leads';
import listingPurchase from './details/listing-purchase';
import listingTodo from './details/listing-todo';
import listingTodoList from './details/listing-todo-list';
import listings from './list/listings';
import openHouses from './list/open-houses';
import openHouse from './details/open-house';
import opportunities from './list/opportunities';
import projects from './list/projects';
import properties from './list/properties';
import relatedCampaigns from './list/related-campaigns';
import relatedCases from './list/related-cases';
import relatedCompanies from './list/related-companies';
import relatedContacts from './list/related-contacts';
import relatedLeads from './list/related-leads';
import relatedListings from './list/related-listings';
import relatedOffers from './list/related-offers';
import relatedOpportunities from './list/related-opportunities';
import relatedRequests from './list/related-requests';
import relatedUsers from './list/related-users';
import requests from './list/requests';
import requestDetach from './details/request-detach';
import requestAttach from './details/request-attach';
import socialInterests from './list/social-interests';
import stageHistory from './list/stage-history';
import stages from './list/stages';
import task from './details/task';
import note from './details/note';
import tasks from './list/tasks';
import tasksBulk from './bulk/tasks';
import taskComment from './details/task-comment';
import tasksComments from './list/tasks-comments';
import tasksSections from './list/tasks-sections';
import transactions from './list/transactions';
import workspaceMembers from './list/workspace-members';
import workspaces from './list/workspaces';
import relatedEvents from './list/related-events';
import relatedTasks from './list/related-tasks';
import calendarEvent from './details/calendar-event';
import calendarEvents from './list/calendar-events';
import calendarCategories from './list/calendar-categories';
import calendarCategory from './details/calendar-category';
import calendarTypes from './list/calendar-types';
import user from './details/user';
import users from './list/users';
import userAttach from './details/user-attach';
import userDetach from './details/user-detach';
import calendarType from './details/calendar-type';
import activityList from './list/activity-list';
import workspace from './details/workspace';
import file from './details/file';
import files from './list/files';
import campaign from './details/campaign';
import caseDetails from './details/case';
import caseDetach from './details/case-detach';
import offerDetach from './details/offer-detach';
import company from './details/company';
import companyAttach from './details/company-attach';
import companyDetach from './details/company-detach';
import favorite from './details/favorite';
import lead from './details/lead';
import leadDetach from './details/lead-detach';
import leadAttach from './details/lead-attach';
import listing from './details/listing';
import listingDetach from './details/listing-detach';
import opportunity from './details/opportunity';
import opportunityAttach from './details/opportunity-attach';
import opportunityDetach from './details/opportunity-detach';
import property from './details/property';
import request from './details/request';
import transaction from './details/transaction';
import projectTask from './details/project-task';
import listView from './details/list-view';
import listViews from './list/list-views';
import emails from './list/emails';
import email from './details/email';
import emailSend from './details/email-send';
import emailForward from './details/email-forward';
import workspaceActivities from './list/workspace-activities';
import workspaceActivity from './details/workspace-activity';
import recent from './list/recent';
import clearRecent from './list/clear-recent';
import etag from './details/etag';

export default (baseURL: string) => ({
	activityList           : activityList(baseURL),
	batch                  : batch(baseURL),
	bulkUpdate             : bulkUpdate(baseURL),
	calendarCategories     : calendarCategories(baseURL),
	calendarCategory       : calendarCategory(baseURL),
	calendarEvents         : calendarEvents(baseURL),
	calendarType           : calendarType(baseURL),
	calendarTypes          : calendarTypes(baseURL),
	campaign               : campaign(baseURL),
	campaignAttach         : campaignAttach(baseURL),
	campaignDetach         : campaignDetach(baseURL),
	campaigns              : campaigns(baseURL),
	caseAttach             : caseAttach(baseURL),
	caseDetach             : caseDetach(baseURL),
	caseDetails            : caseDetails(baseURL),
	cases                  : cases(baseURL),
	clearRecent            : clearRecent(baseURL),
	collaborationCall      : collaborationCall(baseURL),
	comments               : comments(baseURL),
	companies              : companies(baseURL),
	company                : company(baseURL),
	companyAttach          : companyAttach(baseURL),
	companyDetach          : companyDetach(baseURL),
	contact                : contact(baseURL),
	contactAttach          : contactAttach(baseURL),
	contactDetach          : contactDetach(baseURL),
	contacts               : contacts(baseURL),
	dictionaries           : dictionaries(baseURL),
	documents              : documents(baseURL),
	driveFiles             : driveFiles(baseURL),
	email                  : email(baseURL),
	emailForward           : emailForward(baseURL),
	emails                 : emails(baseURL),
	emailSend              : emailSend(baseURL),
	etag                   : etag(baseURL),
	event                  : calendarEvent(baseURL),
	expenses               : expenses(baseURL),
	favorite               : favorite(baseURL),
	file                   : file(baseURL),
	files                  : files(baseURL),
	folders                : folders(baseURL),
	globalSearch           : globalSearch(baseURL),
	inviteProjectExternal  : inviteProjectExternal(baseURL),
	inviteProjectMember    : inviteProjectMember(baseURL),
	inviteWorkspaceExternal: inviteWorkspaceExternal(baseURL),
	inviteWorkspaceMember  : inviteWorkspaceMember(baseURL),
	invoices               : invoices(baseURL),
	lead                   : lead(baseURL),
	leadAttach             : leadAttach(baseURL),
	leadDetach             : leadDetach(baseURL),
	leads                  : leads(baseURL),
	listing                : listing(baseURL),
	listingDetach          : listingDetach(baseURL),
	listingPurchase        : listingPurchase(baseURL),
	listingTodo            : listingTodo(baseURL),
	listingTodoList        : listingTodoList(baseURL),
	listings               : listings(baseURL),
	listView               : listView(baseURL),
	listViews              : listViews(baseURL),
	note                   : note(baseURL),
	offerDetach            : offerDetach(baseURL),
	openHouse              : openHouse(baseURL),
	openHouses             : openHouses(baseURL),
	opportunities          : opportunities(baseURL),
	opportunity            : opportunity(baseURL),
	opportunityAttach      : opportunityAttach(baseURL),
	opportunityDetach      : opportunityDetach(baseURL),
	projects               : projects(baseURL),
	projectTask            : projectTask(baseURL),
	properties             : properties(baseURL),
	property               : property(baseURL),
	recent                 : recent(baseURL),
	relatedCampaigns       : relatedCampaigns(baseURL),
	relatedCases           : relatedCases(baseURL),
	relatedCompanies       : relatedCompanies(baseURL),
	relatedContacts        : relatedContacts(baseURL),
	relatedEvents          : relatedEvents(baseURL),
	relatedLeads           : relatedLeads(baseURL),
	relatedListings        : relatedListings(baseURL),
	relatedOffers          : relatedOffers(baseURL),
	relatedOpportunities   : relatedOpportunities(baseURL),
	relatedRequests        : relatedRequests(baseURL),
	relatedTasks           : relatedTasks(baseURL),
	relatedUsers           : relatedUsers(baseURL),
	request                : request(baseURL),
	requestAttach          : requestAttach(baseURL),
	requestDetach          : requestDetach(baseURL),
	requests               : requests(baseURL),
	socialInterests        : socialInterests(baseURL),
	stageHistory           : stageHistory(baseURL),
	stages                 : stages(baseURL),
	streamGroup            : streamGroup(baseURL),
	streamGroups           : streamGroups(baseURL),
	task                   : task(baseURL),
	taskComment            : taskComment(baseURL),
	tasks                  : tasks(baseURL),
	tasksBulk              : tasksBulk(baseURL),
	tasksComments          : tasksComments(baseURL),
	tasksSections          : tasksSections(baseURL),
	transaction            : transaction(baseURL),
	transactions           : transactions(baseURL),
	user                   : user(baseURL),
	userAttach             : userAttach(baseURL),
	userDetach             : userDetach(baseURL),
	users                  : users(baseURL),
	workspace              : workspace(baseURL),
	workspaceActivities    : workspaceActivities(baseURL),
	workspaceActivity      : workspaceActivity(baseURL),
	workspaceMembers       : workspaceMembers(baseURL),
	workspaces             : workspaces(baseURL),
});
